# Core AWS Service abstractions
#import socks.ssm
import boto3
import socks.athena
import socks.cloudwatch
import socks.dynamodb
import socks.s3
import socks.secretsmanager
import socks.sqs
import socks.ssm
import socks.sts
import socks.aws_lambda



import boto3
from botocore.exceptions import ClientError
import json, csv, os

#TODO: Are there other common object types that should be supported?
#TODO: Write a unit test
def read_file(bucket, key, encoding='utf-8', session=boto3, region_name='us-east-1', **s3_object_get_kwargs):
    s3_resource = session.resource('s3', region_name=region_name)
    s3_object = s3_resource.Object(bucket, key)

    try:
        content = s3_object.get(**s3_object_get_kwargs)['Body'].read().decode(encoding)
    except ClientError as e:
        error_code = e.response['Error']['Code']
        print(f"ERROR: {error_code}")
        raise e
    else:
        object_format = key.split('.')[-1]
        if object_format == 'json':
            json_content = json.loads(content)
            return json_content
        elif object_format == 'csv':
            return csv.DictReader(content.split())
        else:
            return content

#TODO: Add checking for local filepath.
#TODO: Add error handling.
#TODO: Write a unit test
def download_file(local_path, bucket, key, session=boto3, region_name='us-east-1', **s3_object_download_fileobj_kwargs):
    s3_resource = session.resource('s3', region_name=region_name)
    s3_object = s3_resource.Object(bucket, key)

    try:
        with open(local_path, 'wb') as fileobj:
            #Set kwargs
            s3_object_download_fileobj_kwargs['Fileobj'] = fileobj
            
            response = s3_object.download_fileobj(**s3_object_download_fileobj_kwargs)
    except ClientError as e:
        error_code = e.response['Error']['Code']
        print(f"ERROR: {error_code}")
        raise e
    else:
        return response

#TODO: Add error handling
#TODO: Write a unit test
def write_file(content, bucket, key, session=boto3, region_name='us-east-1', **s3_object_put_kwargs):
    s3_resource = session.resource('s3', region_name=region_name)
    s3_object = s3_resource.Object(bucket, key)
    object_format = key.split('.')[-1]

    #Set kwargs
    s3_object_put_kwargs['Body'] = content

    try:
        response = s3_object.put(**s3_object_put_kwargs)
    except ClientError as e:
        error_code = e.response['Error']['Code']
        print(f"ERROR: {error_code}")
        raise e
    else:
        return response

#TODO: Add error handling.
#TODO: Write a unit test
def upload_file(local_path, bucket, key, session=boto3, region_name='us-east-1', **s3_object_upload_file_kwargs):
    s3_resource = session.resource('s3', region_name=region_name)
    s3_object = s3_resource.Object(bucket, key)

    #Set kwargs
    s3_object_upload_file_kwargs['Filename'] = local_path

    try:
        response = s3_object.upload_file(**s3_object_upload_file_kwargs)
    except ClientError as e:
        error_code = e.response['Error']['Code']
        print(f"ERROR: {error_code}")
        raise e
    else:
        return response

#TODO: Error handling
#TODO: Write a unit test
def delete_file(bucket, key, session=boto3, region_name='us-east-1', **s3_object_delete_kwargs):
    s3_resource = session.resource('s3', region_name=region_name)
    s3_object = s3_resource.Object(bucket, key)

    try:
        response = s3_object.delete(**s3_object_delete_kwargs)
    except ClientError as e:
        error_code = e.response['Error']['Code']
        print(f"ERROR: {error_code}")
        raise e
    else:
        return response 

#TODO: Error handling
#TODO: Add parameter to return folders as well
#TODO: Write a unit test
def list_files(bucket, prefix, session=boto3, region_name='us-east-1', **s3_bucket_objects_filer_kwargs):
    s3_resource = session.resource('s3', region_name=region_name)
    s3_bucket = s3_resource.Bucket(bucket)

    #Set kwargs
    s3_bucket_objects_filer_kwargs['Prefix'] = prefix

    try:
        objects = s3_bucket.objects.filter(**s3_bucket_objects_filer_kwargs)
    except ClientError as e:
        error_code = e.response['Error']['Code']
        print(f"ERROR: {error_code}")
        raise e
    else:
        return [object_summary.key for object_summary in objects if object_summary.key[-1] != '/']

#TODO: Return something
#TODO: Error Handling
#TODO: Write a unit test
def download_folder(bucket, prefix, local_path, session=boto3, region_name='us-east-1', **s3_client_download_file_kwargs):
    s3_client = session.client('s3', region_name=region_name)

    paginator = s3_client.get_paginator('list_objects')
    for result in paginator.paginate(Bucket=bucket, Delimiter='/', Prefix=prefix):
        if result.get('CommonPrefixes') is not None:
            for subdir in result.get('CommonPrefixes'):
                download_folder(bucket, subdir.get('Prefix'), local_path)
        if result.get('Contents') is not None:
            for file in result.get('Contents'):
                if not os.path.exists(os.path.dirname(local_path + os.sep + file.get('Key'))):
                    os.makedirs(os.path.dirname(local_path + os.sep + file.get('Key')))
                if not file.get('Key').endswith('/'):
                    #Set kwargs
                    s3_client_download_file_kwargs['Bucket'] = bucket
                    s3_client_download_file_kwargs['Key'] = file.get('Key')
                    s3_client_download_file_kwargs['Filename'] = local_path + os.sep + file.get('Key')
                    s3_client.download_file(**s3_client_download_file_kwargs)


def object_exists(bucket, key, session=boto3, region_name='us-east-1'):
    s3_resource = session.resource('s3', region_name=region_name)

    try:
        s3_resource.Object(bucket, key).load()
    except ClientError as e:
        error_code = e.response['Error']['Code']
        if error_code == "404":
            return False
        else:
            print(f"ERROR: {error_code}")
            raise e
    else:
        return True


import boto3
from botocore.exceptions import ClientError

class Env():
    def __init__(self, env, session=boto3, region_name='us-east-1'):
        self.env = env
        self.region_name = region_name
        self.session = session

    def get_secret(self, name, **secrets_client_get_secret_value_kwargs):
        secret_name = '{}_{}'.format(self.env, name)
        return get_secret(secret_name, self.session, self.region_name, **secrets_client_get_secret_value_kwargs)

#TODO: Write a unit test
def env(env, session=boto3, region_name='us-east-1'):
    return Env(env, session, region_name)

#TODO: Write a unit test
def get_secret(secret_name, session=boto3, region_name='us-east-1', **secrets_client_get_secret_value_kwargs):
    secrets_client = session.client('secretsmanager', region_name=region_name)

    #Set kwargs
    secrets_client_get_secret_value_kwargs['SecretId'] = secret_name

    try:
        response = secrets_client.get_secret_value(**secrets_client_get_secret_value_kwargs)
    except ClientError as e:
        if e.response['Error']['Code'] == 'DecryptionFailureException':
            raise e
        elif e.response['Error']['Code'] == 'InternalServiceErrorException':
            raise e
        elif e.response['Error']['Code'] == 'InvalidParameterException':
            print("The request had invalid params:", e)
        elif e.response['Error']['Code'] == 'InvalidRequestException':
            print("The request was invalid due to:", e)
        elif e.response['Error']['Code'] == 'ResourceNotFoundException':
            print("The requested secret " + secret_name + " was not found")
    else:
        if 'SecretString' in response:
            return response['SecretString']
        else:
            return response['SecretBinary']


import boto3
from botocore.exceptions import ClientError

import datetime
import json
import time

#TODO: Error handling
#TODO: Write a unit test
def get_sequence_token(group_name, stream_name, session=boto3, region_name='us-east-1'):
    cw_client = session.client('logs', region_name=region_name)
    while True:
        try:
            response = cw_client.describe_log_streams(logGroupName=group_name, logStreamNamePrefix=stream_name)
        except ClientError as e:
            error_code = e.response['Error']['Code']

            #Wait and try again if we are being throttled
            if error_code in ['ThrottlingException']:
                print('Cloudwatch describe_log_streams is throttling you. Trying again in 2 seconds.')
                time.sleep(2)
            else:
                print(f"ERROR: {error_code}")
                raise e
        else:
            if response['logStreams'] and response['logStreams'][0]['logStreamName'] == stream_name:
                if('uploadSequenceToken' in response['logStreams'][0]):
                    return response['logStreams'][0]['uploadSequenceToken']
                else:
                    return None
            else:
                cw_client.create_log_stream(logGroupName=group_name, logStreamName=stream_name)
                return None


#TODO: Should this return something?
#TODO: Error handling
#TODO: Write a unit test
def push_json_log(log_body, group_name, stream_name, session=boto3, region_name='us-east-1', **cw_client_put_log_events_kwargs):
    cw_client = session.client('logs', region_name=region_name)
    log_time = datetime.datetime.now();

    #Set kwargs
    cw_client_put_log_events_kwargs['logGroupName'] = group_name
    cw_client_put_log_events_kwargs['logStreamName'] = stream_name
    cw_client_put_log_events_kwargs['logEvents'] = [
        {
            'timestamp': int(log_time.timestamp() * 1000.0),
            'message': json.dumps(log_body)
        }
    ]

    sequence_token = get_sequence_token(group_name, stream_name, session=session, region_name=region_name)
    if sequence_token:
        cw_client_put_log_events_kwargs['sequenceToken'] = sequence_token
    try:
        response = cw_client.put_log_events(**cw_client_put_log_events_kwargs)
    except ClientError as e:
        error_code = e.response['Error']['Code']
        print(f"ERROR: {error_code}")
        raise e
    else:
        return response


import boto3
import time
from botocore.exceptions import ClientError

class Env():
    def __init__(self, env, session=boto3, region_name='us-east-1'):
        self.env = env
        self.region_name = region_name
        self.session = session

    def get_parameter(self, name, encrypted=False, **ssm_client_get_parameter_kwargs):
        parameter_name = '{}_{}'.format(self.env, name)
        return get_parameter(parameter_name, encrypted, self.session, self.region_name, **ssm_client_get_parameter_kwargs)

def env(env, session=boto3, region_name='us-east-1'):
    return Env(env, session, region_name)

def get_parameter(parameter_name, encrypted=False, session=boto3, region_name='us-east-1', **ssm_client_get_parameter_kwargs):
    ssm_client = session.client('ssm', region_name=region_name)

    #Set kwargs
    ssm_client_get_parameter_kwargs['Name'] = parameter_name
    ssm_client_get_parameter_kwargs['WithDecryption'] = encrypted
    
    while True:
        try:
            parameter = ssm_client.get_parameter(**ssm_client_get_parameter_kwargs)
        except ClientError as e:
            error_code = e.response['Error']['Code']

            if error_code in ['ProvisionedThroughputExceededException', 'ThrottlingException']:
                time.sleep(2)
            else:
                print(f"ERROR: {error_code}")
                raise e
        else:
            return parameter['Parameter']['Value']

        


import boto3, json
from botocore.exceptions import ClientError


def invoke_lambda_function(function_name, pay_load = None, session=boto3, region_name='us-east-1', **lambda_client_invoke_kwargs):
    lambda_client = session.client('lambda', region_name=region_name)

    #Set kwargs
    lambda_client_invoke_kwargs['FunctionName'] = function_name
    lambda_client_invoke_kwargs['InvocationType'] = "Event"

    if pay_load:
        lambda_client_invoke_kwargs['Payload'] = json.dumps(pay_load)
    
    try:
        response = lambda_client.invoke(**lambda_client_invoke_kwargs)
    except ClientError as e:  
        error_code = e.response['Error']['Code']
        print(f"ERROR: {error_code}")
        raise e 
    else:
        return response  



import boto3
import socks.s3
import time, csv, os

def query(sql_statement, database, bucket, key='results', local_filepath=None, workgroup=None, session=boto3, region_name='us-east-1', **athena_start_query_execution_kwargs):
    athena_client = session.client('athena', region_name=region_name) 

    athena_start_query_execution_kwargs['QueryString'] = sql_statement
    if 'QueryExecutionContext' in athena_start_query_execution_kwargs:
        athena_start_query_execution_kwargs['QueryExecutionContext']['Database'] = database
    else:
        athena_start_query_execution_kwargs['QueryExecutionContext'] = {'Database': database}

    if 'ResultConfiguration' in athena_start_query_execution_kwargs:
        athena_start_query_execution_kwargs['ResultConfiguration']['OutputLocation'] = f"s3://{bucket}/{key}"
    else:
        athena_start_query_execution_kwargs['ResultConfiguration'] = {'OutputLocation': f"s3://{bucket}/{key}"}

    if workgroup:
        athena_start_query_execution_kwargs['WorkGroup']=workgroup


    start_query_response = athena_client.start_query_execution(**athena_start_query_execution_kwargs)
    execution_id = start_query_response['QueryExecutionId']
    
    #Check State of Query, Continue Waiting Until State is 'SUCCEEDED', 'FAILED', or 'CANCELLED'
    while True:
        stats = athena_client.get_query_execution(QueryExecutionId = execution_id)
        status = stats['QueryExecution']['Status']['State']
        if status in ['SUCCEEDED', 'FAILED', 'CANCELLED']:
            break
        time.sleep(0.2)  # 200ms

    if status == 'SUCCEEDED':
        #Attempt to Make New Local Directory if Doesn't Exist
        if local_filepath:
            os.makedirs(os.path.dirname(local_filepath), exist_ok=True)
            
            if socks.s3.object_exists(bucket, f"{key}/{execution_id}.csv", session, region_name):
                socks.s3.download_file(local_filepath, bucket, f"{key}/{execution_id}.csv", session, region_name)
                with open(local_filepath) as f:
                    data = [{k: v for k,v in row.items()} for row in csv.DictReader(f, skipinitialspace=True)]
                
                return data
            elif socks.s3.object_exists(bucket, f"{key}/{execution_id}.txt", session, region_name):
                socks.s3.download_file(local_filepath, bucket, f"{key}/{execution_id}.txt", session, region_name)
                with open(local_filepath) as f:
                    data = f.read()
                
                return data
            else:
                print(f"ERROR: Athena query did not succeed and ended with state {status['State']} because {status['StateChangeReason']}")
                return None
        else:
            return True
    elif status == 'FAILED':
        status = athena_client.get_query_execution(QueryExecutionId = execution_id)['QueryExecution']['Status']
        print(f"ERROR: Athena query did not succeed and ended with state {status['State']} because {status['StateChangeReason']}")
        return None
    elif status == 'CANCELLED':
        print("INFO: Athena query was cancelled")
        return None


import boto3
from botocore.exceptions import ClientError
import json

#TODO: Look into other parameters we may want to offer the user
#TODO: Write a unit test
def send_message(message, queue_url, session=boto3, region_name='us-east-1', **sqs_client_send_message_kwargs):
    sqs_client = session.client('sqs', region_name=region_name)
    
    #Convert json/dict to string for the user
    if isinstance(message, dict):
        message = json.dumps(message)

    #Set kwargs
    sqs_client_send_message_kwargs['QueueUrl'] = queue_url
    sqs_client_send_message_kwargs['MessageBody'] = message

    try:
        response = sqs_client.send_message(**sqs_client_send_message_kwargs)
    except ClientError as e:
        error_code = e.response['Error']['Code']
        print(f"ERROR: {error_code}")
        raise e
    else:
        return response

#TODO: Look into other parameters we may want to offer the user
#TODO: Write a unit test
def receive_message(queue_url, max_num_messages, session=boto3, region_name='us-east-1', **sqs_client_receive_message_kwargs):
    sqs_client = session.client('sqs', region_name=region_name)

    #Set kwargs
    sqs_client_receive_message_kwargs['QueueUrl'] = queue_url
    sqs_client_receive_message_kwargs['MaxNumberOfMessages'] = max_num_messages

    try:
        response = sqs_client.receive_message(**sqs_client_receive_message_kwargs)
    except ClientError as e:
        error_code = e.response['Error']['Code']
        print(f"ERROR: {error_code}")
        raise e
    else:
        message = response['Messages'][0]
        receipt_handle = response['ReceiptHandle']

        return message, receipt_handle

#TODO: Write a unit test
def delete_message(queue_url, receipt_handle, session=boto3, region_name='us-east-1', **sqs_client_delete_message_kwargs):
    sqs_client = session.client('sqs', region_name=region_name)

    #Set kwargs
    sqs_client_delete_message_kwargs['QueueUrl'] = queue_url
    sqs_client_delete_message_kwargs['ReceiptHandle'] = receipt_handle

    try:
        response = sqs_client.delete_message(**sqs_client_delete_message_kwargs)
    except ClientError as e:
        error_code = e.response['Error']['Code']
        print(f"ERROR: {error_code}")
        raise e
    else:
        return response


import boto3
from botocore.exceptions import ClientError

def assume_role(arn, session=boto3, region_name='us-east-1', **sts_client_assume_role_kwargs):
    sts_client = session.client('sts', region_name=region_name)

    #Set kwargs
    sts_client_assume_role_kwargs['RoleArn'] = arn
    sts_client_assume_role_kwargs['RoleSessionName'] = 'socks_sts_assume_role'

    try:
        response = sts_client.assume_role(**sts_client_assume_role_kwargs)
    except ClientError as e:
        error_code = e.response['Error']['Code']
        print(f"ERROR: {error_code}")
        raise e
    else:
        session = boto3.Session(
                aws_access_key_id=response['Credentials']['AccessKeyId'],
                aws_secret_access_key=response['Credentials']['SecretAccessKey'],
                aws_session_token=response['Credentials']['SessionToken'])
        return session


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['socks']

package_data = \
{'': ['*']}

install_requires = \
['boto3>=1.9,<2.0']

setup_kwargs = {
    'name': 'aws-socks',
    'version': '0.2.5',
    'description': 'A wrapper for boto3 to provide one-liners for common AWS tasks.',
    'long_description': '\n# aws-socks\n\n---\n\n<p align="center"> \n    Most AWS tasks are solved problems. Stop reinventing the wheel.\n    <br> \n</p>\n\n## About\nCurrent Version: 0.2.5\n\n`socks` is a Python library designed to abstract common AWS tasks as one liners. It is opinionated in the pursuit to provide the most performant implementation that can be leveraged generally, but also attempts to offer reasonable levels of customization to the developer by supporting most boto3 functionality.\n\nThis package attempts to provide performant abstractions of the most common AWS tasks for the most common AWS services, so you can spend less time finding the best way to get that object from S3 and more time on what you actually want to do with that object (as an example).\n\nThis package is not comprehensive across all (or even most) AWS services at this time, but I hope to grow this overtime so a majority of the AWS tasks you find yourself re-solving or copying from one repo to the next can be implemented here in the most efficient way.\n\n\n## Getting Started\nPlease note socks has not yet hit the 1.0 release so breaking API changes may occur. I\'ll try to limit those as possible and document them when they happen, but if you\'d like to use socks it might be a good idea to lock your version in your requirements.txt file.\n\nIf you\'d like to install the library locally or without code warp/spawn you can use the following install command:\n\n`pip install aws-socks`\n\nTo upgrade an existing install use:\n\n`pip install --upgrade aws-socks`\n\nOnce installed use `import socks` to start using it.\n\n### Prerequisites {docsify-ignore}\n- The only external dependency for this library is boto3 which is packaged within the library.\n- This package expects Python version 3.6 and up. There are no plans to support previous versions of Python.\n\n## Contributors\n- [@jones-chris](https://github.com/jones-chris) - Maintainer\n- [@devenjarvis](https://github.com/devenjarvis) - Maintainer\n- [@artkinghur](https://github.com/artkinghur) - SSM get_parameter exception handling\n- [@arief-akbarr](https://github.com/arief-akbar) - Scan Dynamo Operation, Invoke Lambda Function\n- [@ds0440](https://github.com/ds0440) - Support of boto3 kwargs',
    'author': 'Deven Jarvis',
    'author_email': 'devenjarvis@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/devenjarvis/aws-socks',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



import boto3
import json
import decimal
from botocore.exceptions import ClientError
from boto3.dynamodb.conditions import Key

# Helper class to convert a DynamoDB item to JSON.
class DecimalEncoder(json.JSONEncoder):
    def default(self, o):
        if isinstance(o, decimal.Decimal):
            if o % 1 > 0:
                return float(o)
            else:
                return int(o)
        return super(DecimalEncoder, self).default(o)

#TODO: Write a unit test
def add_item(table_name, item, session=boto3, region_name='us-east-1', **dynamo_table_put_item_kwargs):
    dynamodb_resource = session.resource('dynamodb', region_name=region_name)
    table = dynamodb_resource.Table(table_name)

    #Set kwargs
    dynamo_table_put_item_kwargs['Item'] = item

    try:
        response = table.put_item(**dynamo_table_put_item_kwargs)
    except ClientError as e:
        error_code = e.response['Error']['Code']
        print(f"ERROR: {error_code}")
        raise e
    else:
        return json.dumps(response, cls=DecimalEncoder)

#TODO: Add error handling
#TODO: Write a unit test
def update_item(table_name, key, item, session=boto3, region_name='us-east-1', **dynamo_table_update_item_kwargs):
    dynamodb_resource = session.resource('dynamodb', region_name=region_name)
    table = dynamodb_resource.Table(table_name)

    #Build ExpressionAttributeValues and UpdateExpression
    expression_attribute_values = {}
    update_expression = "SET "
    for item_key, item_value in item.items():
        expression_attribute_values[f":{item_key}"] = item_value
        update_expression += f"{item_key} = :{item_key}, "
        
    #Clean up trailing comma
    update_expression = update_expression[:-2]

    #Set kwargs
    dynamo_table_update_item_kwargs['Key'] = key
    dynamo_table_update_item_kwargs['UpdateExpression'] = update_expression
    dynamo_table_update_item_kwargs['ExpressionAttributeValues'] = expression_attribute_values

    try:
        response = table.update_item(**dynamo_table_update_item_kwargs)
    except ClientError as e:
        error_code = e.response['Error']['Code']
        print(f"ERROR: {error_code}")
        raise e
    else:
        return json.dumps(response, cls=DecimalEncoder)

#TODO: Add error handling
#TODO: Write a unit test
def get_item(table_name, key, session=boto3, region_name='us-east-1', **dynamo_table_get_item_kwargs):
    dynamodb_resource = session.resource('dynamodb', region_name=region_name)
    table = dynamodb_resource.Table(table_name)

    #Set kwargs
    dynamo_table_get_item_kwargs['Key'] = key

    try:
        response = table.get_item(**dynamo_table_get_item_kwargs)
    except ClientError as e:
        error_code = e.response['Error']['Code']
        print(f"ERROR: {error_code}")
        raise e
    else:
        return response['Item']

#TODO: Write a unit test
def delete_item(table_name, key, session=boto3, region_name='us-east-1', **dynamo_table_delete_item_kwargs):
    dynamodb_resource = session.resource('dynamodb', region_name=region_name)
    table = dynamodb_resource.Table(table_name)

    #Set kwargs
    dynamo_table_delete_item_kwargs['Key'] = key

    try:
        response = table.delete_item(**dynamo_table_delete_item_kwargs)
    except ClientError as e:
        error_code = e.response['Error']['Code']
        print(f"ERROR: {error_code}")
        raise e
    else:
        return json.dumps(response, cls=DecimalEncoder)

#TODO: Expand list of supported operators. Not really ready for use.
#TODO: Add error handling
def query_table(table_name: str, key_condition_expression, session=boto3, region_name: str = 'us-east-1', **dynamo_table_query_kwargs):
    dynamodb_resource = session.resource('dynamodb', region_name=region_name)
    table = dynamodb_resource.Table(table_name)

    #Set kwargs
    dynamo_table_query_kwargs['KeyConditionExpression'] = key_condition_expression

    response = table.query(**dynamo_table_query_kwargs)

    results = []
    for i in response['Items']:
        results.append(json.dumps(i, cls=DecimalEncoder))

    # If LastEvaluatedKey is in response, then there are more records to retrieve.  Add the LastEvaluatedKey to kwargs
    # and query again until all items are retrieved.
    while 'LastEvaluatedKey' in response:
        dynamo_table_query_kwargs['LastEvaluatedKey'] = response['LastEvaluatedKey']

        response = table.query(**dynamo_table_query_kwargs)

        for i in response['Items']:
            results.append(json.dumps(i, cls=DecimalEncoder))

    return results

def scan_table(table_name, session=boto3, region_name='us-east-1', **dynamo_table_scan_kwargs):
        dynamodb = session.resource('dynamodb', region_name = region_name)
        table = dynamodb.Table(table_name)

        response = table.scan(**dynamo_table_scan_kwargs)

        results = []
        for i in response['Items']:
            results.append(json.dumps(i, cls=DecimalEncoder))

        # Continue scanning if there are more records
        while 'LastEvaluatedKey' in response:
            scan_kwargs = {'ExclusiveStartKey':response['LastEvaluatedKey']}
            for kwarg in dynamo_table_scan_kwargs:
                scan_kwargs[kwarg] = dynamo_table_scan_kwargs[kwarg]
            response = table.scan(**scan_kwargs)
            for i in response['Items']:
                results.append(json.dumps(i, cls=DecimalEncoder))

        return results 